#!/usr/bin/python
# -*- coding: utf-8 -*-

# Cagou: desktop/mobile frontend for Salut à Toi XMPP client
# Copyright (C) 2016 Jérôme Poisson (goffi@goffi.org)

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


from sat.core import log as logging
log = logging.getLogger(__name__)
from sat.core.i18n import _
from cagou.core.constants import Const as C
from kivy.uix.boxlayout import BoxLayout
from kivy.uix.listview import ListView
from kivy.adapters.listadapter import ListAdapter
from kivy import properties
from kivy.uix.behaviors import ButtonBehavior
from cagou.core import cagou_widget
from cagou import G


PLUGIN_INFO = {
    "name": _(u"widget selector"),
    "import_name": C.WID_SELECTOR,
    "main": "WidgetSelector",
    "description": _(u"show available widgets and allow to select one"),
    "icon_small": u"{media}/icons/muchoslava/png/selector_new_32.png",
    "icon_medium": u"{media}/icons/muchoslava/png/selector_new_44.png"
}


class WidgetSelItem(ButtonBehavior, BoxLayout):
    plugin_info = properties.DictProperty()

    def __init__(self, **kwargs):
        super(WidgetSelItem, self).__init__(**kwargs)

    def select(self, *args):
        log.debug(u"widget selection: {}".format(self.plugin_info["name"]))
        factory = self.plugin_info["factory"]
        G.host.switchWidget(self, factory(self.plugin_info, None, profiles=iter(G.host.profiles)))

    def deselect(self, *args):
        pass


class WidgetSelector(cagou_widget.CagouWidget):

    def __init__(self):
        super(WidgetSelector, self).__init__()
        self.adapter = ListAdapter(
            data=G.host.getPluggedWidgets(except_cls=self.__class__),
            cls=WidgetSelItem,
            args_converter=self.dataConverter,
            selection_mode='single',
            allow_empty_selection=True,
           )
        self.add_widget(ListView(adapter=self.adapter))

    @classmethod
    def factory(cls, plugin_info, target, profiles):
        return cls()

    def dataConverter(self, idx, plugin_info):
        return {"plugin_info": plugin_info}


PLUGIN_INFO["factory"] = WidgetSelector.factory
